@@ -22,19 +22,20 @@ class CollectionCloner:
         self.src_db_name = self.config.get('src_db_name', '')
         self.src_col = self.config.get('src_col', '')
         self.src_db = self.config.get('src_db', '')
+        self.src_ip = self.config.get('src_ip', '')
         self.des_db_name = self.config.get('des_db_name', '')
-        self.des_user = self.config.get('des_user', '')
-        self.des_pass = self.config.get('des_pass', '')
+        self.user = self.config.get('user', '')
+        self.password = self.config.get('password', '')
         self.des_col = self.config.get('des_col', '')
         self.des_ip = self.config.get('des_ip', '')
         
-        if mode == 'll':
+        if self.mode == 'll':
             self.clone_local_to_local()
-        elif mode == 'lr':
+        elif self.mode == 'lr':
             self.clone_local_to_remote()
-        elif mode == 'rl':
+        elif self.mode == 'rl':
             self.clone_remote_to_local()
-        elif mode == 'rr':
+        elif self.mode == 'rr':
             self.clone_remote_to_remote()
         else:
             logger.error('Allowed modes: ll, lr, rl, and rr')
@@ -96,24 +97,20 @@ class CollectionCloner:
         # Destinatoion 
         if self.des_db_name == '':
             logger.error('No des_db_name is found')
-        if self.des_user == '':
-            logger.error('No des_user is found')
-        if self.des_pass == '':
-            logger.error('No des_pass is found')
+        if self.user == '':
+            logger.error('No user is found')
+        if self.password == '':
+            logger.error('No password is found')
         if self.des_col == '':
             logger.error('No des_col is found')
         if self.des_ip == '':
             logger.error('No des_ip is found')
-        if self.des_user == '':
-            logger.error('No des_user is found')
-        if self.des_pass == '':
-            logger.error('No des_pass is found')
 
         try:
             des_server = SSHTunnelForwarder(
                 des_ip,
-                ssh_username=self.des_user,
-                ssh_password=self.des_pass,
+                ssh_username=self.user,
+                ssh_password=self.password,
                 remote_bind_address=('127.0.0.1', 27017)
             )
             des_server.start()
@@ -126,21 +123,21 @@ class CollectionCloner:
         self.start_cloning()
         
     def clone_remote_to_local(self):
-        if src_db_name == '':
+        if self.src_db_name == '':
             logger.error('No src_db_name is found')
-        if src_user == '':
+        if self.user == '':
             logger.error('No src_user is found')
-        if src_pass == '':
+        if self.password == '':
             logger.error('No src_pass is found')
-        if src_col == '':
+        if self.src_col == '':
             logger.error('No src_col is found')
-        if src_ip == '':
+        if self.src_ip == '':
             logger.error('No src_ip is found')
         try:
             src_server = SSHTunnelForwarder(
                 src_ip,
-                ssh_username=src_user,
-                ssh_password=src_pass,
+                ssh_username=self.user,
+                ssh_password=self.password,
                 remote_bind_address=('127.0.0.1', 27017)
             )
             src_server.start()
@@ -197,18 +194,14 @@ class CollectionCloner:
         # Destinatoion 
         if self.des_db_name == '':
             logger.error('No des_db_name is found')
-        if self.des_user == '':
-            logger.error('No des_user is found')
-        if self.des_pass == '':
-            logger.error('No des_pass is found')
-        if self.des_col == '':
-            logger.error('No des_col is found')
-        if self.des_ip == '':
-            logger.error('No des_ip is found')
         if self.user == '':
             logger.error('No user is found')
         if self.password == '':
             logger.error('No password is found')
+        if self.des_col == '':
+            logger.error('No des_col is found')
+        if self.des_ip == '':
+            logger.error('No des_ip is found')
 
         try:
             des_server = SSHTunnelForwarder(
